package org.testing.web;

import static com.jayway.restassured.RestAssured.given;
import java.io.File;
import static javax.ws.rs.core.MediaType.APPLICATION_JSON;
import static org.apache.http.HttpStatus.*;
import static org.hamcrest.Matchers.*;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.testng.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.resolver.api.maven.Maven;
import org.testng.annotations.Test;

public class ValidationIT extends Arquillian {
    private static final File WEBAPP_SRC = new File("src/main/webapp");

    @Deployment(name = "ROOT")
    public static WebArchive createDeployment() {
        return ShrinkWrap.create(WebArchive.class, "ROOT.war")
            .addAsLibraries(Maven.resolver().loadPomFromFile("pom.xml").importRuntimeDependencies().resolve().withTransitivity().asFile())
            .addAsResource("logback.xml")
            .addPackages(true, "org.testing")
            .addAsManifestResource(new File(WEBAPP_SRC, "META-INF/context.xml"))
            .setWebXML(new File(WEBAPP_SRC, "WEB-INF/web.xml"));
    }

    @Test
    public void testQueryParamValidation() {
        given().
            accept(APPLICATION_JSON).
        expect().
            statusCode(is(SC_BAD_REQUEST)).
            contentType(is(APPLICATION_JSON)).
         when().
            get("http://localhost:8084/testing?key=bad-value").
        body().
            prettyPrint();
    }

}
